@@ -7,8 +7,9 @@ import traceback
 from .api_handler import APIHandler
 from .account import Account
 from .user import User
+from .token import Token
 
-__version__ = "1.0.12"
+__version__ = "1.0.15"
 
 
 class FreedomClient(object):
@@ -22,7 +23,6 @@ class FreedomClient(object):
         username (str): Username.
         password (str): Password.
     """
-
     def __init__(self, token=None, secret=None, username=None, password=None, url=None, **api_args):
         self.api = APIHandler.get_instance(
             url=url,
@@ -88,6 +88,59 @@ class FreedomClient(object):
         result = self.api.call("GET", "/accounts", params=params)
         return result
 
+    def create_token(
+            self,
+            allowed_actions,
+            accounts,
+            devices,
+            description,
+            create_secret=False,
+            params=None,
+            raw=True,
+            **kwargs
+        ):
+        """:obj:`dict`: Creates a token and returns it.
+
+        Args:
+            description (str) Token description 
+            allowed_actions (dict): Allowed actions for the new token. 
+            accounts (list or *): List of accounts ids on which this token will have access.
+                Use '*' if the token needs access to all accounts
+            devices (list or *): List of devices ids on which this token will have access.
+                Use '*' if the token needs access to all devices
+            create_secret (bool): If true, will create a token with a secret.
+            params (dict): Optional query parameters.
+            raw (bool): If true, will return the raw response of the API.
+                Otherwise it will create a Token object and return it with the returned token id.
+            **kwargs (dict): All extra attributes for the new token.
+        """
+        body = {
+            "allowed_actions": allowed_actions,
+            "accounts": accounts,
+            "devices": devices,
+            "description": description,
+        }
+        body.update(kwargs)
+        if create_secret:
+            if params is None:
+                params = {}
+            params['create_secret'] = 'true'
+        result = self.api.call("POST", "/tokens", data=body, params=params)
+        if raw:
+            return result
+        else:
+            return Token(result['token'], api=self.api)
+
+    def delete_token(self, token_id, params=None):
+        """Deletes a specified token.
+
+        Args:
+            token_id (str): The Token id
+        """
+
+        result = self.api.call("DELETE", "/tokens/{}".format(token_id), params=params)
+        return result
+
     def report_issue(
             self,
             message,
